==> estateplat-common-1.2.4-20191105.011458-173-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcZsSd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lj</a>
 * @version 1.0, 2015-05-12
 * @description 过渡数据锁定表
 */

@Table(name = "bdc_bdczssd")
public class BdcBdcZsSd implements Serializable, InsertVo {
    @Id
    private String sdid;//锁定id
    private String cqzh;//产权证号
    private String zsid;//证书ID
    private String bdclx;//不动产类型
    private String proid;//项目id
    private Integer xzzt;//限制状态
    private String xzyy;//限制原因
    private String xztype;//限制类型
    private String sdr;//锁定人
    private Date sdsj;//锁定时间
    private String jsr;//解锁人
    private Date jssj;//解锁时间
    private String jbr;//经办人
    private String jsyy;//解锁原因
    private String bz;//备注
    private Integer sdnx;//锁定年限
    private String sdlcgzlid;//锁定流程工作流ID
    private String jslcgzlid;//解锁流程工作流ID
    private String sdjg;//锁定结构
    private String sdwh;//锁定文号
    private String jsjg;//解锁机构
    private String jswh;//解锁文号

    public String getSdid() {
        return sdid;
    }

    public void setSdid(String sdid) {
        this.sdid = sdid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getXzzt() {
        return xzzt;
    }

    public void setXzzt(Integer xzzt) {
        this.xzzt = xzzt;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getXztype() {
        return xztype;
    }

    public void setXztype(String xztype) {
        this.xztype = xztype;
    }

    public String getSdr() {
        return sdr;
    }

    public void setSdr(String sdr) {
        this.sdr = sdr;
    }

    public Date getSdsj() {
        return sdsj;
    }

    public void setSdsj(Date sdsj) {
        this.sdsj = sdsj;
    }

    public String getJsr() {
        return jsr;
    }

    public void setJsr(String jsr) {
        this.jsr = jsr;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getJsyy() {
        return jsyy;
    }

    public void setJsyy(String jsyy) {
        this.jsyy = jsyy;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBz() {
        return bz;
    }

    public Integer getSdnx() {
        return sdnx;
    }

    public void setSdnx(Integer sdnx) {
        this.sdnx = sdnx;
    }

    public String getSdlcgzlid() {
        return sdlcgzlid;
    }

    public void setSdlcgzlid(String sdlcgzlid) {
        this.sdlcgzlid = sdlcgzlid;
    }

    public String getJslcgzlid() {
        return jslcgzlid;
    }

    public void setJslcgzlid(String jslcgzlid) {
        this.jslcgzlid = jslcgzlid;
    }

    public String getSdjg() {
        return sdjg;
    }

    public void setSdjg(String sdjg) {
        this.sdjg = sdjg;
    }

    public String getSdwh() {
        return sdwh;
    }

    public void setSdwh(String sdwh) {
        this.sdwh = sdwh;
    }

    public String getJsjg() {
        return jsjg;
    }

    public void setJsjg(String jsjg) {
        this.jsjg = jsjg;
    }

    public String getJswh() {
        return jswh;
    }

    public void setJswh(String jswh) {
        this.jswh = jswh;
    }
}

==> estateplat-common-1.2.4-20201202.111846-565-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcZsSd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lj</a>
 * @version 1.0, 2015-05-12
 * @description 过渡数据锁定表
 */

@Table(name = "bdc_bdczssd")
public class BdcBdcZsSd implements Serializable, InsertVo {
    @Id
    private String sdid;//锁定id
    private String cqzh;//产权证号
    private String zsid;//证书ID
    private String bdclx;//不动产类型
    private String proid;//项目id
    private Integer xzzt;//限制状态
    private String xzyy;//限制原因
    private String xztype;//限制类型
    private String sdr;//锁定人
    private Date sdsj;//锁定时间
    private String jsr;//解锁人
    private Date jssj;//解锁时间
    private String jbr;//经办人
    private String jsyy;//解锁原因
    private String bz;//备注
    private Integer sdnx;//锁定年限
    private String sdlcgzlid;//锁定流程工作流ID
    private String jslcgzlid;//解锁流程工作流ID
    private String sdjg;//锁定结构
    private String sdwh;//锁定文号
    private String jsjg;//解锁机构
    private String jswh;//解锁文号
    private String sdywh;//锁定业务号
    private String jsywh;//解锁业务号
    private String xzfw;//限制范围
    private String xzsqr;//限制申请人
    private String bzxr;//被执行人
    private Date xzkssj;//限制开始时间
    private Date xzjssj;//限制结束时间
    private String xzsdr;//限制送达人
    private String xzsdrlxdh;//限制送达人联系电话
    private Date xzsdsj;//限制送达时间
    private String xzqlbh;//限制权利编号

    public String getSdid() {
        return sdid;
    }

    public void setSdid(String sdid) {
        this.sdid = sdid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Integer getXzzt() {
        return xzzt;
    }

    public void setXzzt(Integer xzzt) {
        this.xzzt = xzzt;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getXztype() {
        return xztype;
    }

    public void setXztype(String xztype) {
        this.xztype = xztype;
    }

    public String getSdr() {
        return sdr;
    }

    public void setSdr(String sdr) {
        this.sdr = sdr;
    }

    public Date getSdsj() {
        return sdsj;
    }

    public void setSdsj(Date sdsj) {
        this.sdsj = sdsj;
    }

    public String getJsr() {
        return jsr;
    }

    public void setJsr(String jsr) {
        this.jsr = jsr;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getJsyy() {
        return jsyy;
    }

    public void setJsyy(String jsyy) {
        this.jsyy = jsyy;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBz() {
        return bz;
    }

    public Integer getSdnx() {
        return sdnx;
    }

    public void setSdnx(Integer sdnx) {
        this.sdnx = sdnx;
    }

    public String getSdlcgzlid() {
        return sdlcgzlid;
    }

    public void setSdlcgzlid(String sdlcgzlid) {
        this.sdlcgzlid = sdlcgzlid;
    }

    public String getJslcgzlid() {
        return jslcgzlid;
    }

    public void setJslcgzlid(String jslcgzlid) {
        this.jslcgzlid = jslcgzlid;
    }

    public String getSdjg() {
        return sdjg;
    }

    public void setSdjg(String sdjg) {
        this.sdjg = sdjg;
    }

    public String getSdwh() {
        return sdwh;
    }

    public void setSdwh(String sdwh) {
        this.sdwh = sdwh;
    }

    public String getJsjg() {
        return jsjg;
    }

    public void setJsjg(String jsjg) {
        this.jsjg = jsjg;
    }

    public String getJswh() {
        return jswh;
    }

    public void setJswh(String jswh) {
        this.jswh = jswh;
    }

    public String getSdywh() {
        return sdywh;
    }

    public void setSdywh(String sdywh) {
        this.sdywh = sdywh;
    }

    public String getJsywh() {
        return jsywh;
    }

    public void setJsywh(String jsywh) {
        this.jsywh = jsywh;
    }

    public String getXzfw() {
        return xzfw;
    }

    public void setXzfw(String xzfw) {
        this.xzfw = xzfw;
    }

    public String getXzsqr() {
        return xzsqr;
    }

    public void setXzsqr(String xzsqr) {
        this.xzsqr = xzsqr;
    }

    public String getBzxr() {
        return bzxr;
    }

    public void setBzxr(String bzxr) {
        this.bzxr = bzxr;
    }

    public Date getXzkssj() {
        return xzkssj;
    }

    public void setXzkssj(Date xzkssj) {
        this.xzkssj = xzkssj;
    }

    public Date getXzjssj() {
        return xzjssj;
    }

    public void setXzjssj(Date xzjssj) {
        this.xzjssj = xzjssj;
    }

    public String getXzsdr() {
        return xzsdr;
    }

    public void setXzsdr(String xzsdr) {
        this.xzsdr = xzsdr;
    }

    public String getXzsdrlxdh() {
        return xzsdrlxdh;
    }

    public void setXzsdrlxdh(String xzsdrlxdh) {
        this.xzsdrlxdh = xzsdrlxdh;
    }

    public Date getXzsdsj() {
        return xzsdsj;
    }

    public void setXzsdsj(Date xzsdsj) {
        this.xzsdsj = xzsdsj;
    }

    public String getXzqlbh() {
        return xzqlbh;
    }

    public void setXzqlbh(String xzqlbh) {
        this.xzqlbh = xzqlbh;
    }
}
